from bmi_tester.bmipytest import load_component

entry_point = "os:getcwd"
module_name, cls_name = entry_point.split(":")


def test_component_is_not_string():
    component = load_component(entry_point)
    assert not isinstance(component, str)


def test_component_is_classname():
    component = load_component(entry_point)
    assert component.__name__ == cls_name



from bmi_tester.api import check_unit_is_dimensionless
from bmi_tester.api import check_unit_is_time
from bmi_tester.api import check_unit_is_valid


def test_check_valid_units():
    assert check_unit_is_valid("m")
    assert check_unit_is_valid("m / s")
    assert check_unit_is_valid("m s-1")
    assert check_unit_is_valid("N m")
    assert check_unit_is_valid("N.m")
    assert check_unit_is_valid("m^2")
    assert check_unit_is_valid("m2")
    assert check_unit_is_valid("")
    assert check_unit_is_valid("1")


def test_check_invalid_units():
    assert not check_unit_is_valid("foo")
    assert not check_unit_is_valid("m ** 2")
    assert not check_unit_is_valid("-")


def test_dimensionless_units():
    assert check_unit_is_dimensionless("")
    assert check_unit_is_dimensionless("1")
    assert not check_unit_is_dimensionless("m")
    # assert not check_unit_is_dimensionless("-")


def test_time_units():
    assert check_unit_is_time("s")
    assert check_unit_is_time("d")
    assert check_unit_is_time("yr")
    assert check_unit_is_time("seconds since 1970-01-01")
    assert check_unit_is_time("seconds since 1970-01-01 00:00:00 UTC")
    assert check_unit_is_time("days since 1970-01-01 00:00:00 UTC")
    assert check_unit_is_time("years since 1970-01-01 00:00:00 UTC")

    assert not check_unit_is_time("m")



import os

from bmi_tester.api import check_bmi


def touch_file(fname):
    with open(fname, "w"):
        pass


def test_bmi_check(tmpdir):
    with tmpdir.as_cwd():
        touch_file("input.yaml")
        assert (
            check_bmi(
                "bmi_tester.bmi:Bmi", input_file="input.yaml", extra_args=["-vvv"]
            )
            == 0
        )


def test_bmi_check_with_manifest_as_list(tmpdir):
    with tmpdir.as_cwd():
        touch_file("input.yaml")
        assert (
            check_bmi(
                "bmi_tester.bmi:Bmi",
                extra_args=["-vvv"],
                input_file="input.yaml",
                manifest=["input.yaml"],
            )
            == 0
        )


def test_bmi_check_with_manifest_as_string(tmpdir):
    with tmpdir.as_cwd():
        with open("manifest.txt", "w") as fp:
            fp.write(os.linesep.join(["input.yaml", "data.dat"]))
        touch_file("input.yaml")
        touch_file("data.dat")
        assert (
            check_bmi(
                "bmi_tester.bmi:Bmi",
                extra_args=["-vvv"],
                input_file="input.yaml",
                manifest="manifest.txt",
            )
            == 0
        )



from bmi_tester._version import __version__
from bmi_tester.api import check_bmi
from bmi_tester.api import check_unit_is_dimensionless
from bmi_tester.api import check_unit_is_time
from bmi_tester.api import check_unit_is_valid

__all__ = [
    "__version__",
    "check_bmi",
    "check_unit_is_valid",
    "check_unit_is_time",
    "check_unit_is_dimensionless",
]
